@@ -1,17 +1,19 @@
-aov.test <- function(y, group, alpha = 0.05, na.rm = TRUE, verbose = TRUE) {
+aov.test <- function(formula, data, alpha = 0.05, na.rm = TRUE, verbose = TRUE) {
+
+  dp=as.character(formula)
+  DNAME <- paste(dp[[2L]], "and", dp[[3L]])
 
-  dname1 <- deparse(substitute(y))
-  dname2 <- deparse(substitute(group))
-  DNAME <- paste(dname1, "and", dname2)
   METHOD <- "One-Way Analysis of Variance"
 
 
  if (na.rm){
-    completeObs <- complete.cases(y, group)
-    y <- y[completeObs]
-    group <- group[completeObs]
+    completeObs <- complete.cases(data)
+    data <- data[completeObs,]
   }
 
+  y=data[,dp[[2L]]]
+  group=data[,dp[[3L]]]
+
 
 n <- length(y)
 x.levels <- levels(factor(group))
@@ -71,9 +73,10 @@ result <- list()
 result$statistic <- Ftest
 result$parameter <- c(df1,df2)
 result$p.value <- p.value
+result$alpha <- alpha
 result$method <- METHOD 
-result$y <- y
-result$group <- group
+result$data <- data
+result$formula <- formula
 
 attr(result, "class") <- "owt"
 invisible(result)
