@@ -1,16 +1,19 @@
-james.test <- function(y, group, alpha = 0.05, na.rm = TRUE, verbose = TRUE) {
+james.test <- function(formula, data, alpha = 0.05, na.rm = TRUE, verbose = TRUE) {
   
-  dname1 <- deparse(substitute(y))
-  dname2 <- deparse(substitute(group))
-  DNAME <- paste(dname1, "and", dname2)
+  dp=as.character(formula)
+  DNAME <- paste(dp[[2L]], "and", dp[[3L]])
+
   METHOD <- "James Second Order Test"
 
-if (na.rm){
-    completeObs <- complete.cases(y, group)
-    y <- y[completeObs]
-    group <- group[completeObs]
+ if (na.rm){
+    completeObs <- complete.cases(data)
+    data <- data[completeObs,]
   }
 
+  y=data[,dp[[2L]]]
+  group=data[,dp[[3L]]]
+
+
   n <- length(y)
   x.levels <- levels(factor(group))
   J<-length(x.levels)
@@ -101,9 +104,10 @@ if (verbose) {
 result <- list()
 result$statistic <- Jtest
 result$criticalValue  <- CV
+result$alpha <- alpha
 result$method <- METHOD 
-result$y <- y
-result$group <- group
+result$data <- data
+result$formula <- formula
 
 attr(result, "class") <- "jt"
 invisible(result)
